@@ -1,12 +1,22 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ----setup, echo=FALSE, message=FALSE-----------------------------------------
+pkgs <- c(
+  "datawizard",
+  "dplyr",
+  "htmltools"
+)
+
+if (!all(vapply(pkgs, requireNamespace, quietly = TRUE, FUN.VALUE = logical(1L)))) {
+  knitr::opts_chunk$set(eval = FALSE)
+}
+
+## ----load, echo=FALSE, message=FALSE------------------------------------------
 library(datawizard)
-library(poorman)
+library(dplyr)
 library(htmltools)
 
 set.seed(123)
@@ -72,6 +82,9 @@ data_select(iris, -is.numeric)
 ## -----------------------------------------------------------------------------
 data_select(iris, -(1:2))
 
+## -----------------------------------------------------------------------------
+data_select(iris, -(Petal.Length:Species))
+
 ## -----------------------------------------------------------------------------
 data_select(iris, exclude = c("Sepal.Length", "Petal.Width"))
 
@@ -79,13 +92,13 @@ data_select(iris, exclude = starts_with("Sep", "Peta"))
 
 ## -----------------------------------------------------------------------------
 my_function <- function(data, selection) {
-  find_columns(data, select = selection)
+  extract_column_names(data, select = selection)
 }
-my_function(iris, c("Sepal.Length"))
+my_function(iris, "Sepal.Length")
 my_function(iris, starts_with("Sep"))
 
 my_function_2 <- function(data, pattern) {
-  find_columns(data, select = starts_with(pattern))
+  extract_column_names(data, select = starts_with(pattern))
 }
 my_function_2(iris, "Sep")
 
